@@ -35,12 +35,12 @@ def set_default_credentials():
 
 
 def get_bigquery_storage_client(credentials=None):
-    from google.cloud import bigquery_storage_v1beta1
+    from google.cloud import bigquery_storage
 
     if credentials is None:
         credentials = get_credentials()
 
-    return bigquery_storage_v1beta1.BigQueryStorageClient(credentials=credentials)
+    return bigquery_storage.BigQueryReadClient(credentials=credentials)
 
 
 def _get_result_schema(sql, bq_client=None):
@@ -182,7 +182,7 @@ def _bq_table_to_pandas(table):
 
 def _bq_cell_magic(line, query):
     from IPython.core import magic_arguments
-    from google.cloud.bigquery.magics import _cell_magic
+    from google.cloud.bigquery.magics.magics import _cell_magic
     import time
 
     start = time.time()
