@@ -57,14 +57,12 @@ def get_spark(scale=0, queue=None):
     import tempfile
     from pyspark.sql import SparkSession
     from skt.vault_utils import get_secrets
+    from pyspark import version as spark_version
+
+    is_spark_3 = spark_version.__version__ >= "3.0.0"
 
     tmp_uuid = str(uuid.uuid4())
     app_name = f"skt-{os.environ.get('USER', 'default')}-{tmp_uuid}"
-    if not queue:
-        if "JUPYTERHUB_USER" in os.environ:
-            queue = "dmig_eda"
-        else:
-            queue = "airflow_job"
     os.environ["ARROW_PRE_0_15_IPC_FORMAT"] = "1"
 
     key = get_secrets("gcp/sktaic-datahub/dataflow")["config"]
@@ -73,6 +71,43 @@ def get_spark(scale=0, queue=None):
         key_file.write(key.encode())
         os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = key_file.name
 
+    if not queue:
+        if "JUPYTERHUB_USER" in os.environ:
+            queue = "dmig_eda"
+        else:
+            queue = "airflow_job"
+
+    bigquery_jars = (
+        "hdfs:///jars/spark-bigquery-with-dependencies_2.12-0.21.0.jar"
+        if is_spark_3
+        else "hdfs:///jars/spark-bigquery-with-dependencies_2.11-0.17.3.jar"
+    )
+
+    if queue == "nrt":
+        spark = (
+            SparkSession.builder.config("spark.app.name", app_name)
+            .config("spark.driver.memory", "6g")
+            .config("spark.executor.memory", "4g")
+            .config("spark.shuffle.service.enabled", "true")
+            .config("spark.driver.maxResultSize", "6g")
+            .config("spark.rpc.message.maxSize", "1024")
+            .config("spark.executor.core", "4")
+            .config("spark.executor.instances", "32")
+            .config("spark.yarn.queue", queue)
+            .config("spark.ui.enabled", "false")
+            .config("spark.port.maxRetries", "128")
+            .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+            .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+            .config(
+                "spark.jars",
+                bigquery_jars,
+            )
+            .enableHiveSupport()
+            .getOrCreate()
+        )
+        spark.conf.set("spark.sql.execution.arrow.enabled", "true")
+        return spark
+
     if scale in [1, 2, 3, 4]:
         spark = (
             SparkSession.builder.config("spark.app.name", app_name)
@@ -88,7 +123,7 @@ def get_spark(scale=0, queue=None):
             .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
             .config(
                 "spark.jars",
-                "hdfs:///jars/spark-bigquery-with-dependencies_2.11-0.17.3.jar",
+                bigquery_jars,
             )
             .enableHiveSupport()
             .getOrCreate()
@@ -108,33 +143,54 @@ def get_spark(scale=0, queue=None):
             .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
             .config(
                 "spark.jars",
-                "hdfs:///jars/spark-bigquery-with-dependencies_2.11-0.17.3.jar",
+                bigquery_jars,
             )
             .enableHiveSupport()
             .getOrCreate()
         )
     else:
-        spark = (
-            SparkSession.builder.config("spark.app.name", app_name)
-            .config("spark.driver.memory", "6g")
-            .config("spark.executor.memory", "8g")
-            .config("spark.shuffle.service.enabled", "true")
-            .config("spark.dynamicAllocation.enabled", "true")
-            .config("spark.dynamicAllocation.maxExecutors", "200")
-            .config("spark.driver.maxResultSize", "6g")
-            .config("spark.rpc.message.maxSize", "1024")
-            .config("spark.yarn.queue", queue)
-            .config("spark.ui.enabled", "false")
-            .config("spark.port.maxRetries", "128")
-            .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
-            .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
-            .config(
-                "spark.jars",
-                "hdfs:///jars/spark-bigquery-with-dependencies_2.11-0.17.3.jar",
+        if is_spark_3:
+            spark = (
+                SparkSession.builder.config("spark.app.name", app_name)
+                .config("spark.driver.memory", "8g")
+                .config("spark.executor.memory", "8g")
+                .config("spark.executor.instances", "8")
+                .config("spark.driver.maxResultSize", "6g")
+                .config("spark.rpc.message.maxSize", "1024")
+                .config("spark.yarn.queue", queue)
+                .config("spark.ui.enabled", "false")
+                .config("spark.port.maxRetries", "128")
+                .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+                .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+                .config(
+                    "spark.jars",
+                    bigquery_jars,
+                )
+                .enableHiveSupport()
+                .getOrCreate()
+            )
+        else:
+            spark = (
+                SparkSession.builder.config("spark.app.name", app_name)
+                .config("spark.driver.memory", "6g")
+                .config("spark.executor.memory", "8g")
+                .config("spark.shuffle.service.enabled", "true")
+                .config("spark.dynamicAllocation.enabled", "true")
+                .config("spark.dynamicAllocation.maxExecutors", "200")
+                .config("spark.driver.maxResultSize", "6g")
+                .config("spark.rpc.message.maxSize", "1024")
+                .config("spark.yarn.queue", queue)
+                .config("spark.ui.enabled", "false")
+                .config("spark.port.maxRetries", "128")
+                .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+                .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+                .config(
+                    "spark.jars",
+                    bigquery_jars,
+                )
+                .enableHiveSupport()
+                .getOrCreate()
             )
-            .enableHiveSupport()
-            .getOrCreate()
-        )
     spark.conf.set("spark.sql.execution.arrow.enabled", "true")
     return spark
 
